@@ -3,10 +3,10 @@
  *                         All rights reserved.
  * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
- * 
+ *
  * Additional copyrights may follow
- * 
- * $HEADER$	
+ *
+ * $HEADER$
  */
 
 #include "oshmem_config.h"
@@ -29,7 +29,7 @@ SHMEM_GENERATE_FORTRAN_BINDINGS_SUB (void,
         shmem_complex_put_,
         shmem_complex_put__,
         shmem_complex_put_f,
-        (FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI_Fint *length, MPI_Fint *pe), 
+        (FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI_Fint *length, MPI_Fint *pe),
         (target,source,length,pe) )
 
 void shmem_complex_put_f(FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI_Fint *length, MPI_Fint *pe)
@@ -37,9 +37,9 @@ void shmem_complex_put_f(FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI
     size_t complex_type_size = 0;
     ompi_datatype_type_size(&ompi_mpi_cplex.dt, &complex_type_size);
 
-    MCA_SPML_CALL(put(FPTR_2_VOID_PTR(target), 
-        OMPI_FINT_2_INT(*length) * complex_type_size, 
-        FPTR_2_VOID_PTR(source), 
+    MCA_SPML_CALL(put(oshmem_ctx_default, FPTR_2_VOID_PTR(target),
+        OMPI_FINT_2_INT(*length) * complex_type_size,
+        FPTR_2_VOID_PTR(source),
         OMPI_FINT_2_INT(*pe)));
 }
 
